# boardgame-research  [![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat-square)](http://makeapullrequest.com)

This is a list of boardgame research. They are primarily related to "solving/playing/learning" games (by various different approaches), or
occasionaly about designing or meta-aspects of the game. This doesn't cover all aspects of each game (notably missing social-science stuff), but
should be of interest to anyone interested in boardgames and their optimal play. While there is a ton of easily accessible research on games like
Chess and Go, finding prior work on more contemporary games can be a bit hard. This list focuses on the latter. If you are interested in well-researched
games like Chess, Go, Hex, take a look at the [Chess programming wiki](https://www.chessprogramming.org/Games) instead. The list also covers some computer-games that fall under similar themes.

Exported versions are available in the following formats:

- [Zotero RDF](boardgame-research.rdf)
- [BibTeX](boardgame-research.bib)

Watch the repository to get the latest updates for now.

If you aren't able to access any paper on this list, please [try using Sci-Hub](https://en.wikipedia.org/wiki/Sci-Hub) or [reach out to me](https://captnemo.in/contact/).

<!-- START doctoc generated TOC please keep comment here to allow auto update -->
<!-- DON'T EDIT THIS SECTION, INSTEAD RE-RUN doctoc TO UPDATE -->
**Table of Contents**  *generated with [DocToc](https://github.com/thlorenz/doctoc)*

- [Azul](#azul)
- [Blokus](#blokus)
- [Carcassonne](#carcassonne)
- [Diplomacy](#diplomacy)
- [Dixit](#dixit)
- [Dominion](#dominion)
- [Hanabi](#hanabi)
- [Hive](#hive)
- [Jenga](#jenga)
- [Kingdomino](#kingdomino)
- [Lost Cities](#lost-cities)
- [Mafia](#mafia)
- [Magic: the Gathering](#magic-the-gathering)
- [Modern Art: The card game](#modern-art-the-card-game)
- [Monopoly](#monopoly)
- [Monopoly Deal](#monopoly-deal)
- [Nmbr9](#nmbr9)
- [Pandemic](#pandemic)
- [Patchwork](#patchwork)
- [Pentago](#pentago)
- [Quixo](#quixo)
- [Race for the Galaxy](#race-for-the-galaxy)
- [The Resistance: Avalon](#the-resistance-avalon)
- [Risk](#risk)
- [Santorini](#santorini)
- [Scotland Yard](#scotland-yard)
- [Secret Hitler](#secret-hitler)
- [Set](#set)
- [Settlers of Catan](#settlers-of-catan)
- [Shobu](#shobu)
- [Terra Mystica](#terra-mystica)
- [Tetris Link](#tetris-link)
- [Ticket to Ride](#ticket-to-ride)
- [Ultimate Tic-Tac-Toe](#ultimate-tic-tac-toe)
- [Uno](#uno)
- [Yahtzee](#yahtzee)
- [Mobile Games](#mobile-games)
  - [2048](#2048)
- [Game Design](#game-design)
  - [Accessibility](#accessibility)
- [Frameworks/Toolkits](#frameworkstoolkits)

<!-- END doctoc generated TOC please keep comment here to allow auto update -->

# Azul
- [A summary of a dissertation on Azul](https://old.reddit.com/r/boardgames/comments/hxodaf/update_i_wrote_my_dissertation_on_azul/) (unpublished)

# Blokus
- [Blokus Game Solver](https://digitalcommons.calpoly.edu/cpesp/290/)

# Carcassonne
- [Playing Carcassonne with Monte Carlo Tree Search](https://arxiv.org/abs/2009.12974)

# Diplomacy
- [Human-Level Performance in No-Press Diplomacy via Equilibrium Search](https://arxiv.org/abs/2010.02923)
- [Learning to Play No-Press Diplomacy with Best Response Policy Iteration ](https://arxiv.org/abs/2006.04635)
- [No Press Diplomacy: Modeling Multi-Agent Gameplay ](https://arxiv.org/abs/1909.02128)
- [Agent Madoff: A Heuristic-Based Negotiation Agent For The Diplomacy Strategy Game ](https://arxiv.org/abs/1902.06996)

# Dixit
- [Creative Captioning: An AI Grand Challenge Based on the Dixit Board Game](https://arxiv.org/abs/2010.00048)
- [Dixit: Interactive Visual Storytelling via Term Manipulation](https://arxiv.org/abs/1903.02230)

# Dominion

There is a [simulator](https://dominionsimulator.wordpress.com/f-a-q/) and the code behind
[the Dominion server running councilroom.com](https://github.com/mikemccllstr/dominionstats/) is available. councilroom has the [best and worst openings](http://councilroom.com/openings), [optimal card ratios](http://councilroom.com/optimal_card_ratios), [Card winning stats](http://councilroom.com/supply_win) and lots of other empirical research. The [Dominion Strategy Forum](http://forum.dominionstrategy.com/index.php) is another good general resource.

- [Clustering Player Strategies from Variable-Length Game Logs in Dominion](https://arxiv.org/abs/1811.11273)

# Hanabi
- [Improving Policies via Search in Cooperative Partially Observable Games](https://arxiv.org/abs/1912.02318) (FB) [[code](https://github.com/facebookresearch/Hanabi_SPARTA)] - Current best result.
- [Re-determinizing MCTS in Hanabi](https://ieee-cog.org/2020/papers2019/paper_17.pdf)
- [Hanabi is NP-hard, Even for Cheaters who Look at Their Cards](https://arxiv.org/abs/1603.01911)
- [Evolving Agents for the Hanabi 2018 CIG Competition](https://ieeexplore.ieee.org/abstract/document/8490449)
- [Aspects of the Cooperative Card Game Hanabi](https://link.springer.com/chapter/10.1007/978-3-319-67468-1_7)
- [How to Make the Perfect Fireworks Display: Two Strategies for Hanabi](https://doi.org/10.4169/math.mag.88.5.323)
- [Playing Hanabi Near-Optimally](https://link.springer.com/chapter/10.1007/978-3-319-71649-7_5)
- [Evaluating and modelling Hanabi-playing agents](https://doi.org/10.1109/CEC.2017.7969465)
- [An intentional AI for hanabi](https://ieeexplore.ieee.org/abstract/document/8080417)
- [The Hanabi challenge: A new frontier for AI research](https://doi.org/10.1016/j.artint.2019.103216) [[arXiv](https://arxiv.org/abs/1902.00506)]] (DeepMind)
- [Solving Hanabi: Estimating Hands by Opponent's Actions in Cooperative Game with Incomplete Information](https://www.aaai.org/ocs/index.php/WS/AAAIW15/paper/view/10167/10193)
- [A Browser-based Interface for the Exploration and Evaluation of Hanabi AIs](http://fdg2017.org/papers/FDG2017_demo_Hanabi.pdf)
- [I see what you see: Integrating eye tracking into Hanabi playing agents](http://www.exag.org/wp-content/uploads/2018/10/AIIDE-18_Upload_112.pdf)
- [The 2018 Hanabi competition](https://doi.org/10.1109/CIG.2019.8848008)
- [Diverse Agents for Ad-Hoc Cooperation in Hanabi](https://doi.org/10.1109/CIG.2019.8847944) [[arXiv](https://arxiv.org/pdf/2004.13710v2.pdf)]
- [State of the art Hanabi bots + simulation framework in rust](https://github.com/WuTheFWasThat/hanabi.rs)
- [A strategy simulator for the well-known cooperative card game Hanabi](https://github.com/rjtobin/HanSim)
- [A framework for writing bots that play Hanabi](https://github.com/Quuxplusone/Hanabi)
- [Evaluating the Rainbow DQN Agent in Hanabi with Unseen Partners](https://arxiv.org/abs/2004.13291)
- [Operationalizing Intentionality to Play Hanabi with Human Players](https://doi.org/10.1109/TG.2020.3009359)
- [Behavioral Evaluation of Hanabi Rainbow DQN Agents and Rule-Based Agents](https://ojs.aaai.org//index.php/AIIDE/article/view/7404) [[pdf](https://ojs.aaai.org/index.php/AIIDE/article/view/7404/7333)]
- [Playing mini-Hanabi card game with Q-learning](http://id.nii.ac.jp/1001/00205046/)
- [Generating and Adapting to Diverse Ad-Hoc Cooperation Agents in Hanabi](https://arxiv.org/abs/2004.13710)
- [Hanabi Open Agend Dataset](https://github.com/aronsar/hoad) - [[ACM](https://dl.acm.org/doi/abs/10.5555/3461017.3461244)]

# Hive
- [On the complexity of Hive](https://dspace.library.uu.nl/handle/1874/396955)

# Jenga
- [Maximum genus of the Jenga like configurations](https://arxiv.org/abs/1708.01503)
- [Jidoukan Jenga: Teaching English through remixing games and game rules](https://www.llpjournal.org/2020/04/13/jidokan-jenga.html)

# Kingdomino
- [Monte Carlo Methods for the Game Kingdomino](https://doi.org/10.1109/CIG.2018.8490419) [[arXiv](https://arxiv.org/abs/1807.04458)]
- [NP-completeness of the game Kingdomino](https://arxiv.org/abs/1909.02849)

# Lost Cities
- [Applying Neural Networks and Genetic Programming to the Game Lost Cities](http://digital.library.wisc.edu/1793/79080)

# Mafia
- [A mathematical model of the Mafia game](https://arxiv.org/abs/1009.1031)
- [Automatic Long-Term Deception Detection in Group Interaction Videos](https://arxiv.org/abs/1905.08617)
- [Human-Side Strategies in the Werewolf Game Against the Stealth Werewolf Strategy](https://link.springer.com/chapter/10.1007/978-3-319-50935-8_9)
- [A Theoretical Study of Mafia Games](https://arxiv.org/abs/0804.0071)

# Magic: the Gathering
- [Magic: the Gathering is as Hard as Arithmetic](https://arxiv.org/abs/2003.05119)
- [Magic: The Gathering is Turing Complete](https://arxiv.org/abs/1904.09828)
- [Neural Networks Models for Analyzing Magic: the Gathering Cards](https://link.springer.com/chapter/10.1007/978-3-030-04179-3_20) [[arXiv](https://arxiv.org/abs/1810.03744)]
- [The Complexity of Deciding Legality of a Single Step of Magic: the Gathering](https://livrepository.liverpool.ac.uk/3029568/1/magic.pdf)
- [Ensemble Determinization in Monte Carlo Tree Search for the Imperfect Information Card Game Magic: The Gathering](https://doi.org/10.1109/TCIAIG.2012.2204883)
- [Magic: The Gathering in Common Lisp](https://pdfs.semanticscholar.org/5fc8/58802f19504ea950e20e31526dc2269b43d8.pdf) [[source](https://github.com/jeffythedragonslayer/maglisp)]
- [Deck Costruction Strategies for Magic:  the Gathering](https://cab.unime.it/journals/index.php/congress/article/viewFile/141/141)
- [Deckbuilding in Magic: The Gathering Using a Genetic Algorithm](http://hdl.handle.net/11250/2462429)
- [Mathematical programming and Magic: The Gathering®](https://commons.lib.niu.edu/handle/10843/19194)
- [Optimal Card-Collecting Strategies for Magic: The Gathering](https://doi.org/10.1080/07468342.2000.11974103)
- [Monte Carlo search applied to card selection in Magic: The Gathering](https://doi.org/10.1109/CIG.2009.5286501)
- [Magic: The Gathering Deck Performance Prediction](http://cs229.stanford.edu/proj2012/HauPlotkinTran-MagicTheGatheringDeckPerformancePrediction.pdf)

# Modern Art: The card game
- [A constraint programming based solver for Modern Art](https://github.com/captn3m0/modernart)

# Monopoly
- [Learning Monopoly Gameplay: A Hybrid Model-Free Deep Reinforcement Learning and Imitation Learning Approach](https://arxiv.org/abs/2103.00683)
- [Negotiation strategy of agents in the MONOPOLY game](https://ieeexplore.ieee.org/abstract/document/1013210)
- [Generating interesting Monopoly boards from open data](https://ieeexplore.ieee.org/abstract/document/6374168)
- [Estimating the probability that the game of Monopoly never ends](https://ieeexplore.ieee.org/abstract/document/5429349)
- [Learning to play Monopoly:A Reinforcement Learning approach](https://www.researchgate.net/profile/Anestis_Fachantidis/publication/289403522_Learning_to_play_monopoly_A_Reinforcement_learning_approach/links/59dd1f3e458515f6efef1904/Learning-to-play-monopoly-A-Reinforcement-learning-approach.pdf)
- [Monopoly as a Markov Process](https://doi.org/10.1080/0025570X.1972.11976187)
- [Learning to Play Monopoly withMonte Carlo Tree Search](https://project-archive.inf.ed.ac.uk/ug4/20181042/ug4_proj.pdf)
- [Monopoly Using Reinforcement Learning ](https://ieeexplore.ieee.org/abstract/document/8929523)
- [A Markovian Exploration of Monopoly](https://pi4.math.illinois.edu/wp-content/uploads/2014/10/Gartland-Burson-Ferguson-Markovopoly.pdf)
- [What's the best Monopoly strategy](https://publications.lakeforest.edu/cgi/viewcontent.cgi?referer=&httpsredir=1&article=1277&context=gss)

# Monopoly Deal
- [Implementation of AI Player on "Monopoly Deal"](https://doi.org/10.1007/978-3-662-46742-8_11)

# Nmbr9
- [Nmbr9 as a Constraint Programming Challenge](https://zayenz.se/blog/post/nmbr9-cp2019-abstract/)

# Pandemic
- [NP-Completeness of Pandemic](https://www.jstage.jst.go.jp/article/ipsjjip/20/3/20_723/_article)

# Patchwork
- [State Representation and Polyomino Placement for the Game Patchwork](https://zayenz.se/blog/post/patchwork-modref2019-paper/)

# Pentago
- [On Solving Pentago](http://www.ke.tu-darmstadt.de/lehre/arbeiten/bachelor/2011/Buescher_Niklas.pdf)

# Quixo
- [Quixo Is Solved](https://arxiv.org/abs/2007.15895)
- [QUIXO is EXPTIME-complete](https://doi.org/10.1016/j.ipl.2020.105995)

# Race for the Galaxy
- [SCOUT: A Case-Based Reasoning Agent for Playing Race for the Galaxy](https://doi.org/10.1007/978-3-319-61030-6_27)

# The Resistance: Avalon
- [Finding Friend and Foe in Multi-Agent Games](https://arxiv.org/abs/1906.02330)

# Risk

- [Mini-Risk: Strategies for a Simplified Board Game](https://doi.org/10.1057/jors.1990.2)
- [A Multi-Agent System for playing the board game Risk](https://www.diva-portal.org/smash/record.jsf?pid=diva2%3A831093&dswid=-4740)
- [Learning the risk board game with classifier systems](https://doi.org/10.1145/508791.508904)
- [Markov Chains and the RISK Board Game](https://doi.org/10.1080/0025570X.1997.11996573)
- [Markov Chains for the RISK Board Game Revisited](https://doi.org/10.1080/0025570X.2003.11953165)
- [RISK Board Game ‐ Battle Outcome Analysis](http://www.c4i.gr/xgeorgio/docs/RISK-board-game%20_rev-3.pdf)
- [Planning an endgame move set for the game RISK](https://doi.org/10.1109/TEVC.2005.856211)
- [RISKy Business: An In-Depth Look at the Game RISK](https://scholar.rose-hulman.edu/rhumj/vol3/iss2/3/)
- [An Intelligent Artificial Player for the Game of Risk](http://www.ke.tu-darmstadt.de/lehre/archiv/ss04/oberseminar/folien/Wolf_Michael-Slides.pdf)
- [Monte Carlo Tree Search for Risk](https://www.sto.nato.int/publications/STO%20Meeting%20Proceedings/STO-MP-SAS-OCS-ORA-2020/MP-SAS-OCS-ORA-2020-WCM-01.pdf) [[Presentation](https://www.sto.nato.int/publications/STO%20Meeting%20Proceedings/STO-MP-SAS-OCS-ORA-2020/MP-SAS-OCS-ORA-2020-WCM-01P.pdf)]

# Santorini
- [A Mathematical Analysis of the Game of Santorini](https://openworks.wooster.edu/independentstudy/8917/)

# Scotland Yard
- [The complexity of Scotland Yard](http://www.illc.uva.nl/Research/Publications/Reports/PP-2006-18.text.pdf)

# Secret Hitler
- [Competing in a Complex Hidden Role Game with Information Set Monte Carlo Tree Search](https://arxiv.org/abs/2005.07156)

# Set
Set has a long history of mathematical research, so this list isn't exhaustive.

- [Game, Set, Math](https://doi.org/10.4169/math.mag.85.2.083)
- [The Joy of SET](https://doi.org/10.1080/00029890.2018.1412661)

# Settlers of Catan
- [The effectiveness of persuasion in The Settlers of Catan ](https://doi.org/10.1109/CIG.2014.6932861)
- [Avoiding Revenge Using Optimal Opponent Ranking Strategy in the Board Game Catan ](https://doi.org/10.4018/IJGCMS.2018040103)
- [Game strategies for The Settlers of Catan](https://doi.org/10.1109/CIG.2014.6932884)
- [Monte-Carlo Tree Search in Settlers of Catan](https://doi.org/10.1007/978-3-642-12993-3_3)
- [Settlers of Catan bot trained using reinforcement learning (MATLAB).](https://jonzia.github.io/Catan/)
- [Trading in a multiplayer board game: Towards an analysis of non-cooperative dialogue](https://escholarship.org/content/qt9zt506xx/qt9zt506xx.pdf)
- [POMCP with Human Preferencesin Settlers of Catan](https://www.aaai.org/ocs/index.php/AIIDE/AIIDE18/paper/viewFile/18091/17217)
- [Reinforcement Learning of Strategies for Settlers of Catan](http://citeseerx.ist.psu.edu/viewdoc/download?doi=10.1.1.561.6293&rep=rep1&type=pdf)
- [Deep Reinforcement Learning in Strategic Board GameEnvironments](https://doi.org/10.1007/978-3-030-14174-5_16) [[pdf](https://hal.archives-ouvertes.fr/hal-02124411/document)]
- [Monte Carlo Tree Search in a Modern Board Game Framework](https://project.dke.maastrichtuniversity.nl/games/files/bsc/Roelofs_Bsc-paper.pdf)
- [The impact of loaded dice in Catan](https://izbicki.me/blog/how-to-cheat-at-settlers-of-catan-by-loading-the-dice-and-prove-it-with-p-values.html)
- [Playing Catan with Cross-dimensional Neural Network](https://arxiv.org/abs/2008.07079)
- [Strategic Dialogue Management via Deep Reinforcement Learning](https://arxiv.org/abs/1511.08099)

# Shobu
- [Shobu AI Playground](https://github.com/JayWalker512/Shobu)
- [Shobu randomly played games dataset](https://www.kaggle.com/bsfoltz/shobu-randomly-played-games-104k)

# Terra Mystica
- [Using Tabu Search Algorithm for Map Generation in the Terra Mystica Tabletop Game](https://arxiv.org/abs/2006.02716)

# [Tetris Link](https://boardgamegeek.com/boardgame/93185/tetris-link)
- [A New Challenge: Approaching Tetris Link with AI](https://arxiv.org/abs/2004.00377)

# Ticket to Ride
- [Evolving maps and decks for ticket to ride](https://doi.org/10.1145/3235765.3235813)
- [Materials for Ticket to Ride Seattle and a framework for making more game boards](https://github.com/dovinmu/ttr_generator)
- [The Difficulty of Learning Ticket to Ride](https://www.eecs.tufts.edu/~jsinapov/teaching/comp150_RL/reports/Nguyen_Dinjian_report.pdf)
- [AI-based Playtesting of Contemporary Board Games](https://doi.org/10.1145/3102071.3102105) [[pdf](http://game.engineering.nyu.edu/wp-content/uploads/2017/06/ticket-ride-fdg2017-camera-ready.pdf)] [[presentation](https://www.rtealwitter.com/slides/2020-JMM.pdf)]

# Ultimate Tic-Tac-Toe
- [At Most 43 Moves, At Least 29: Optimal Strategies and Bounds for Ultimate Tic-Tac-Toe](https://arxiv.org/abs/2006.02353)

# Uno
- [The complexity of UNO](https://arxiv.org/abs/1003.2851)
- [UNO Is Hard, Even for a Single Player](https://doi.org/10.1007/978-3-642-13122-6_15)

# Yahtzee
- [Optimal Solitaire Yahtzee Strategies](http://www.yahtzee.org.uk/optimal_yahtzee_TV.pdf)
- [Nearly Optimal Computer Play in Multi-player Yahtzee](https://doi.org/10.1007/978-3-642-17928-0_23)
- [Computer Strategies for Solitaire Yahtzee](https://doi.org/10.1109/CIG.2007.368089)
- [An optimal strategy for Yahtzee](http://www.cs.loyola.edu/~jglenn/research/optimal_yahtzee.pdf)
- [Yahtzee:  a Large Stochastic Environment for RL Benchmarks](https://pdfs.semanticscholar.org/f5c2/e9c9b17f584f060a73036109f697ac819a23.pdf)
- [Modeling expert problem solving in a game of chance: a Yahtzee case study](https://doi.org/10.1111/1468-0394.00160)
- [Probabilites In Yahtzee](https://doi.org/10.5951/MT.75.9.0751)
- [Optimal Yahtzee performance in multi-player games](https://www.diva-portal.org/smash/get/diva2:668705/FULLTEXT01.pdf)
- [Defensive Yahtzee](https://www.diva-portal.org/smash/get/diva2:817838/FULLTEXT01.pdf)
- [Using  Deep  Q-Learning  to  Compare Strategy  Ladders  of  Yahtzee](https://pdfs.semanticscholar.org/6bec/1c34c8ace65adc95d39cb0c0e589ae392678.pdf)
- [How to Maximize Your Score in Solitaire Yahtzee](http://www-set.win.tue.nl/~wstomv/misc/yahtzee/yahtzee-report-unfinished.pdf)

# Mobile Games
- [Trainyard is NP-Hard](https://arxiv.org/abs/1603.00928)
- [Threes!, Fives, 1024!, and 2048 are Hard](https://arxiv.org/abs/1505.04274)

## 2048
- [Making Change in 2048](https://arxiv.org/abs/1804.07396)
- [Analysis of the Game "2048" and its Generalization in Higher Dimensions](https://arxiv.org/abs/1804.07393)
- [Temporal difference learning of N-tuple networks for the game 2048](https://ieeexplore.ieee.org/abstract/document/6932907)
- [Multi-Stage Temporal Difference Learning for 2048-like Games](https://arxiv.org/abs/1606.07374)
- [On the Complexity of Slide-and-Merge Games](https://arxiv.org/abs/1501.03837)
- [2048 is (PSPACE) Hard, but Sometimes Eas](https://arxiv.org/abs/1408.6315)
- [Systematic Selection of N-Tuple Networks for 2048](https://doi.org/10.1007/978-3-319-50935-8_8)
- [Systematic selection of N-tuple networks with consideration of interinfluence for game 2048](https://doi.org/10.1109/TAAI.2016.7880154)
- [2048 Without New Tiles Is Still Hard](https://drops.dagstuhl.de/opus/volltexte/2016/5885/)
- [An investigation into 2048 AI strategies](https://doi.org/10.1109/CIG.2014.6932920)

# Game Design
- [MDA: A Formal Approach to Game Design and Game Research ](https://www.aaai.org/Papers/Workshops/2004/WS-04-04/WS04-04-001.pdf)
- [Exploring Anonymity in Cooperative Board Games](http://citeseerx.ist.psu.edu/viewdoc/download?doi=10.1.1.225.5554&rep=rep1&type=pdf)

## Accessibility
- [Eighteen Months of Meeple Like Us: An Exploration into the State of Board Game Accessibility](https://doi.org/10.1007/s40869-018-0056-9)
- [Meeple Centred Design: A Heuristic Toolkit for Evaluating the Accessibility of Tabletop Games](https://doi.org/10.1007/s40869-018-0057-8)

# Frameworks/Toolkits
- [RLCard: A Toolkit for Reinforcement Learning in Card Games](https://arxiv.org/abs/1910.04376)
- [GTSA: Game Tree Search Algorithms](https://github.com/AdamStelmaszczyk/gtsa)
- [Design and Implementation of TAG: A Tabletop Games Framework](https://arxiv.org/abs/2009.12065) [[GitHub](https://github.com/GAIGResearch/TabletopGames)]
- [TAG: Tabletop Games Framework](https://github.com/GAIGResearch/TabletopGames)